from __future__ import annotations
from win32more._prelude import *
import win32more.Microsoft.UI
import win32more.Microsoft.UI.Composition
import win32more.Microsoft.UI.Content
import win32more.Microsoft.UI.Dispatching
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Foundation.Numerics
import win32more.Windows.Graphics
import win32more.Windows.UI.Composition
class ContentCoordinateConverter(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentCoordinateConverter
    _classid_ = 'Microsoft.UI.Content.ContentCoordinateConverter'
    @winrt_mixinmethod
    def ConvertScreenToLocalWithPoint(self: win32more.Microsoft.UI.Content.IContentCoordinateConverter, screenPoint: win32more.Windows.Graphics.PointInt32) -> win32more.Windows.Foundation.Point: ...
    @winrt_mixinmethod
    def ConvertLocalToScreenWithPoints(self: win32more.Microsoft.UI.Content.IContentCoordinateConverter, localPoints: PassArray[win32more.Windows.Foundation.Point]) -> ReceiveArray[win32more.Windows.Graphics.PointInt32]: ...
    @winrt_mixinmethod
    def ConvertLocalToScreenWithPointsAndRoundingMode(self: win32more.Microsoft.UI.Content.IContentCoordinateConverter, localPoints: PassArray[win32more.Windows.Foundation.Point], roundingMode: win32more.Microsoft.UI.Content.ContentCoordinateRoundingMode) -> ReceiveArray[win32more.Windows.Graphics.PointInt32]: ...
    @winrt_mixinmethod
    def ConvertLocalToScreenWithRect(self: win32more.Microsoft.UI.Content.IContentCoordinateConverter, localRect: win32more.Windows.Foundation.Rect) -> win32more.Windows.Graphics.RectInt32: ...
    @winrt_mixinmethod
    def ConvertLocalToScreenWithPoint(self: win32more.Microsoft.UI.Content.IContentCoordinateConverter, localPoint: win32more.Windows.Foundation.Point) -> win32more.Windows.Graphics.PointInt32: ...
    @winrt_mixinmethod
    def ConvertScreenToLocalWithPoints(self: win32more.Microsoft.UI.Content.IContentCoordinateConverter, screenPoints: PassArray[win32more.Windows.Graphics.PointInt32]) -> ReceiveArray[win32more.Windows.Foundation.Point]: ...
    @winrt_mixinmethod
    def ConvertScreenToLocalWithRect(self: win32more.Microsoft.UI.Content.IContentCoordinateConverter, screenRect: win32more.Windows.Graphics.RectInt32) -> win32more.Windows.Foundation.Rect: ...
    @winrt_classmethod
    def CreateForWindowId(cls: win32more.Microsoft.UI.Content.IContentCoordinateConverterStatics, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.UI.Content.ContentCoordinateConverter: ...
class ContentCoordinateRoundingMode(Enum, Int32):
    _name_ = 'Microsoft.UI.Content.ContentCoordinateRoundingMode'
    Auto = 0
    Floor = 1
    Round = 2
    Ceiling = 3
class ContentDeferral(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentDeferral
    _classid_ = 'Microsoft.UI.Content.ContentDeferral'
    @winrt_mixinmethod
    def Complete(self: win32more.Microsoft.UI.Content.IContentDeferral) -> Void: ...
class ContentEnvironmentSettingChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentEnvironmentSettingChangedEventArgs
    _classid_ = 'Microsoft.UI.Content.ContentEnvironmentSettingChangedEventArgs'
    @winrt_mixinmethod
    def get_SettingName(self: win32more.Microsoft.UI.Content.IContentEnvironmentSettingChangedEventArgs) -> hstr: ...
    SettingName = property(get_SettingName, None)
class ContentEnvironmentStateChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentEnvironmentStateChangedEventArgs
    _classid_ = 'Microsoft.UI.Content.ContentEnvironmentStateChangedEventArgs'
    @winrt_mixinmethod
    def get_DidAppWindowIdChange(self: win32more.Microsoft.UI.Content.IContentEnvironmentStateChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_DidDisplayIdChange(self: win32more.Microsoft.UI.Content.IContentEnvironmentStateChangedEventArgs) -> Boolean: ...
    DidAppWindowIdChange = property(get_DidAppWindowIdChange, None)
    DidDisplayIdChange = property(get_DidDisplayIdChange, None)
class ContentIsland(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.UI.Content.IContentIsland
    _classid_ = 'Microsoft.UI.Content.ContentIsland'
    @winrt_mixinmethod
    def put_IsIslandEnabled(self: win32more.Microsoft.UI.Content.IContentIsland, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def put_AppData(self: win32more.Microsoft.UI.Content.IContentIsland, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_CoordinateConverter(self: win32more.Microsoft.UI.Content.IContentIsland) -> win32more.Microsoft.UI.Content.ContentCoordinateConverter: ...
    @winrt_mixinmethod
    def get_CustomProperties(self: win32more.Microsoft.UI.Content.IContentIsland) -> win32more.Windows.Foundation.Collections.IPropertySet: ...
    @winrt_mixinmethod
    def get_DispatcherQueue(self: win32more.Microsoft.UI.Content.IContentIsland) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_mixinmethod
    def get_Environment(self: win32more.Microsoft.UI.Content.IContentIsland) -> win32more.Microsoft.UI.Content.ContentIslandEnvironment: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Microsoft.UI.Content.IContentIsland) -> UInt64: ...
    @winrt_mixinmethod
    def get_IsConnected(self: win32more.Microsoft.UI.Content.IContentIsland) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsHitTestVisibleWhenTransparent(self: win32more.Microsoft.UI.Content.IContentIsland) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsHitTestVisibleWhenTransparent(self: win32more.Microsoft.UI.Content.IContentIsland, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsIslandEnabled(self: win32more.Microsoft.UI.Content.IContentIsland) -> Boolean: ...
    @winrt_mixinmethod
    def get_AppData(self: win32more.Microsoft.UI.Content.IContentIsland) -> IInspectable: ...
    @winrt_mixinmethod
    def get_IsIslandVisible(self: win32more.Microsoft.UI.Content.IContentIsland) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsIslandVisible(self: win32more.Microsoft.UI.Content.IContentIsland, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSiteEnabled(self: win32more.Microsoft.UI.Content.IContentIsland) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsSiteVisible(self: win32more.Microsoft.UI.Content.IContentIsland) -> Boolean: ...
    @winrt_mixinmethod
    def get_LayoutDirection(self: win32more.Microsoft.UI.Content.IContentIsland) -> win32more.Microsoft.UI.Content.ContentLayoutDirection: ...
    @winrt_mixinmethod
    def get_RasterizationScale(self: win32more.Microsoft.UI.Content.IContentIsland) -> Single: ...
    @winrt_mixinmethod
    def GetAutomationHostProvider(self: win32more.Microsoft.UI.Content.IContentIsland) -> IInspectable: ...
    @winrt_mixinmethod
    def GetStateChangeDeferral(self: win32more.Microsoft.UI.Content.IContentIsland) -> win32more.Microsoft.UI.Content.ContentDeferral: ...
    @winrt_mixinmethod
    def RequestSize(self: win32more.Microsoft.UI.Content.IContentIsland, size: win32more.Windows.Foundation.Numerics.Vector2) -> Void: ...
    @winrt_mixinmethod
    def add_AutomationProviderRequested(self: win32more.Microsoft.UI.Content.IContentIsland, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentIsland, win32more.Microsoft.UI.Content.ContentIslandAutomationProviderRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AutomationProviderRequested(self: win32more.Microsoft.UI.Content.IContentIsland, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_StateChanged(self: win32more.Microsoft.UI.Content.IContentIsland, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentIsland, win32more.Microsoft.UI.Content.ContentIslandStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_StateChanged(self: win32more.Microsoft.UI.Content.IContentIsland, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_ActualSize(self: win32more.Microsoft.UI.Content.IContentIsland) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def get_IsClosed(self: win32more.Microsoft.UI.IClosableNotifier) -> Boolean: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Microsoft.UI.IClosableNotifier, handler: win32more.Microsoft.UI.ClosableNotifierHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Microsoft.UI.IClosableNotifier, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_FrameworkClosed(self: win32more.Microsoft.UI.IClosableNotifier, handler: win32more.Microsoft.UI.ClosableNotifierHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FrameworkClosed(self: win32more.Microsoft.UI.IClosableNotifier, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_SystemBackdrop(self: win32more.Microsoft.UI.Composition.ICompositionSupportsSystemBackdrop) -> win32more.Windows.UI.Composition.CompositionBrush: ...
    @winrt_mixinmethod
    def put_SystemBackdrop(self: win32more.Microsoft.UI.Composition.ICompositionSupportsSystemBackdrop, value: win32more.Windows.UI.Composition.CompositionBrush) -> Void: ...
    @winrt_classmethod
    def Create(cls: win32more.Microsoft.UI.Content.IContentIslandStatics, Root: win32more.Microsoft.UI.Composition.Visual) -> win32more.Microsoft.UI.Content.ContentIsland: ...
    @winrt_classmethod
    def FindAllForCompositor(cls: win32more.Microsoft.UI.Content.IContentIslandStatics, compositor: win32more.Microsoft.UI.Composition.Compositor) -> ReceiveArray[win32more.Microsoft.UI.Content.ContentIsland]: ...
    @winrt_classmethod
    def FindAllForCurrentThread(cls: win32more.Microsoft.UI.Content.IContentIslandStatics) -> ReceiveArray[win32more.Microsoft.UI.Content.ContentIsland]: ...
    @winrt_classmethod
    def GetByVisual(cls: win32more.Microsoft.UI.Content.IContentIslandStatics, child: win32more.Microsoft.UI.Composition.Visual) -> win32more.Microsoft.UI.Content.ContentIsland: ...
    @winrt_classmethod
    def GetFromId(cls: win32more.Microsoft.UI.Content.IContentIslandStatics, id: UInt64) -> win32more.Microsoft.UI.Content.ContentIsland: ...
    ActualSize = property(get_ActualSize, None)
    AppData = property(get_AppData, put_AppData)
    CoordinateConverter = property(get_CoordinateConverter, None)
    CustomProperties = property(get_CustomProperties, None)
    DispatcherQueue = property(get_DispatcherQueue, None)
    Environment = property(get_Environment, None)
    Id = property(get_Id, None)
    IsClosed = property(get_IsClosed, None)
    IsConnected = property(get_IsConnected, None)
    IsHitTestVisibleWhenTransparent = property(get_IsHitTestVisibleWhenTransparent, put_IsHitTestVisibleWhenTransparent)
    IsIslandEnabled = property(get_IsIslandEnabled, put_IsIslandEnabled)
    IsIslandVisible = property(get_IsIslandVisible, put_IsIslandVisible)
    IsSiteEnabled = property(get_IsSiteEnabled, None)
    IsSiteVisible = property(get_IsSiteVisible, None)
    LayoutDirection = property(get_LayoutDirection, None)
    RasterizationScale = property(get_RasterizationScale, None)
    SystemBackdrop = property(get_SystemBackdrop, put_SystemBackdrop)
    AutomationProviderRequested = event(add_AutomationProviderRequested, remove_AutomationProviderRequested)
    Closed = event(add_Closed, remove_Closed)
    FrameworkClosed = event(add_FrameworkClosed, remove_FrameworkClosed)
    StateChanged = event(add_StateChanged, remove_StateChanged)
class ContentIslandAutomationProviderRequestedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentIslandAutomationProviderRequestedEventArgs
    _classid_ = 'Microsoft.UI.Content.ContentIslandAutomationProviderRequestedEventArgs'
    @winrt_mixinmethod
    def put_AutomationProvider(self: win32more.Microsoft.UI.Content.IContentIslandAutomationProviderRequestedEventArgs, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_AutomationProvider(self: win32more.Microsoft.UI.Content.IContentIslandAutomationProviderRequestedEventArgs) -> IInspectable: ...
    @winrt_mixinmethod
    def get_Handled(self: win32more.Microsoft.UI.Content.IContentIslandAutomationProviderRequestedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Microsoft.UI.Content.IContentIslandAutomationProviderRequestedEventArgs, value: Boolean) -> Void: ...
    AutomationProvider = property(get_AutomationProvider, put_AutomationProvider)
    Handled = property(get_Handled, put_Handled)
class ContentIslandEnvironment(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentIslandEnvironment
    _classid_ = 'Microsoft.UI.Content.ContentIslandEnvironment'
    @winrt_mixinmethod
    def remove_SettingChanged(self: win32more.Microsoft.UI.Content.IContentIslandEnvironment, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayId(self: win32more.Microsoft.UI.Content.IContentIslandEnvironment) -> win32more.Microsoft.UI.DisplayId: ...
    @winrt_mixinmethod
    def add_SettingChanged(self: win32more.Microsoft.UI.Content.IContentIslandEnvironment, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentIslandEnvironment, win32more.Microsoft.UI.Content.ContentEnvironmentSettingChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def get_AppWindowId(self: win32more.Microsoft.UI.Content.IContentIslandEnvironment) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_mixinmethod
    def add_StateChanged(self: win32more.Microsoft.UI.Content.IContentIslandEnvironment, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentIslandEnvironment, win32more.Microsoft.UI.Content.ContentEnvironmentStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_StateChanged(self: win32more.Microsoft.UI.Content.IContentIslandEnvironment, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AppWindowId = property(get_AppWindowId, None)
    DisplayId = property(get_DisplayId, None)
    SettingChanged = event(add_SettingChanged, remove_SettingChanged)
    StateChanged = event(add_StateChanged, remove_StateChanged)
class ContentIslandStateChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentIslandStateChangedEventArgs
    _classid_ = 'Microsoft.UI.Content.ContentIslandStateChangedEventArgs'
    @winrt_mixinmethod
    def get_DidActualSizeChange(self: win32more.Microsoft.UI.Content.IContentIslandStateChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_DidSiteEnabledChange(self: win32more.Microsoft.UI.Content.IContentIslandStateChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_DidSiteVisibleChange(self: win32more.Microsoft.UI.Content.IContentIslandStateChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_DidLayoutDirectionChange(self: win32more.Microsoft.UI.Content.IContentIslandStateChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_DidRasterizationScaleChange(self: win32more.Microsoft.UI.Content.IContentIslandStateChangedEventArgs) -> Boolean: ...
    DidActualSizeChange = property(get_DidActualSizeChange, None)
    DidLayoutDirectionChange = property(get_DidLayoutDirectionChange, None)
    DidRasterizationScaleChange = property(get_DidRasterizationScaleChange, None)
    DidSiteEnabledChange = property(get_DidSiteEnabledChange, None)
    DidSiteVisibleChange = property(get_DidSiteVisibleChange, None)
class ContentLayoutDirection(Enum, Int32):
    _name_ = 'Microsoft.UI.Content.ContentLayoutDirection'
    LeftToRight = 0
    RightToLeft = 1
class ContentSite(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.UI.Content.IContentSite
    _classid_ = 'Microsoft.UI.Content.ContentSite'
    @winrt_mixinmethod
    def get_IsSiteEnabled(self: win32more.Microsoft.UI.Content.IContentSite) -> Boolean: ...
    @winrt_mixinmethod
    def put_ActualSize(self: win32more.Microsoft.UI.Content.IContentSite, value: win32more.Windows.Foundation.Numerics.Vector2) -> Void: ...
    @winrt_mixinmethod
    def get_ClientSize(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_mixinmethod
    def put_ClientSize(self: win32more.Microsoft.UI.Content.IContentSite, value: win32more.Windows.Graphics.SizeInt32) -> Void: ...
    @winrt_mixinmethod
    def get_CoordinateConverter(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Microsoft.UI.Content.ContentCoordinateConverter: ...
    @winrt_mixinmethod
    def get_ActualSize(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def get_Environment(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Microsoft.UI.Content.ContentSiteEnvironment: ...
    @winrt_mixinmethod
    def get_IsConnected(self: win32more.Microsoft.UI.Content.IContentSite) -> Boolean: ...
    @winrt_mixinmethod
    def get_DispatcherQueue(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_mixinmethod
    def put_IsSiteEnabled(self: win32more.Microsoft.UI.Content.IContentSite, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsSiteVisible(self: win32more.Microsoft.UI.Content.IContentSite) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSiteVisible(self: win32more.Microsoft.UI.Content.IContentSite, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_LayoutDirection(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Microsoft.UI.Content.ContentLayoutDirection: ...
    @winrt_mixinmethod
    def put_LayoutDirection(self: win32more.Microsoft.UI.Content.IContentSite, value: win32more.Microsoft.UI.Content.ContentLayoutDirection) -> Void: ...
    @winrt_mixinmethod
    def get_OverrideScale(self: win32more.Microsoft.UI.Content.IContentSite) -> Single: ...
    @winrt_mixinmethod
    def put_OverrideScale(self: win32more.Microsoft.UI.Content.IContentSite, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_ParentScale(self: win32more.Microsoft.UI.Content.IContentSite) -> Single: ...
    @winrt_mixinmethod
    def put_ParentScale(self: win32more.Microsoft.UI.Content.IContentSite, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_RasterizationScale(self: win32more.Microsoft.UI.Content.IContentSite) -> Single: ...
    @winrt_mixinmethod
    def get_RequestedSize(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def get_ShouldApplyRasterizationScale(self: win32more.Microsoft.UI.Content.IContentSite) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShouldApplyRasterizationScale(self: win32more.Microsoft.UI.Content.IContentSite, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_View(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Microsoft.UI.Content.ContentSiteView: ...
    @winrt_mixinmethod
    def GetIslandStateChangeDeferral(self: win32more.Microsoft.UI.Content.IContentSite) -> win32more.Microsoft.UI.Content.ContentDeferral: ...
    @winrt_mixinmethod
    def add_RequestedStateChanged(self: win32more.Microsoft.UI.Content.IContentSite, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentSite, win32more.Microsoft.UI.Content.ContentSiteRequestedStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_RequestedStateChanged(self: win32more.Microsoft.UI.Content.IContentSite, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def get_IsClosed(self: win32more.Microsoft.UI.IClosableNotifier) -> Boolean: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Microsoft.UI.IClosableNotifier, handler: win32more.Microsoft.UI.ClosableNotifierHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Microsoft.UI.IClosableNotifier, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_FrameworkClosed(self: win32more.Microsoft.UI.IClosableNotifier, handler: win32more.Microsoft.UI.ClosableNotifierHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FrameworkClosed(self: win32more.Microsoft.UI.IClosableNotifier, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ActualSize = property(get_ActualSize, put_ActualSize)
    ClientSize = property(get_ClientSize, put_ClientSize)
    CoordinateConverter = property(get_CoordinateConverter, None)
    DispatcherQueue = property(get_DispatcherQueue, None)
    Environment = property(get_Environment, None)
    IsClosed = property(get_IsClosed, None)
    IsConnected = property(get_IsConnected, None)
    IsSiteEnabled = property(get_IsSiteEnabled, put_IsSiteEnabled)
    IsSiteVisible = property(get_IsSiteVisible, put_IsSiteVisible)
    LayoutDirection = property(get_LayoutDirection, put_LayoutDirection)
    OverrideScale = property(get_OverrideScale, put_OverrideScale)
    ParentScale = property(get_ParentScale, put_ParentScale)
    RasterizationScale = property(get_RasterizationScale, None)
    RequestedSize = property(get_RequestedSize, None)
    ShouldApplyRasterizationScale = property(get_ShouldApplyRasterizationScale, put_ShouldApplyRasterizationScale)
    View = property(get_View, None)
    Closed = event(add_Closed, remove_Closed)
    FrameworkClosed = event(add_FrameworkClosed, remove_FrameworkClosed)
    RequestedStateChanged = event(add_RequestedStateChanged, remove_RequestedStateChanged)
class ContentSiteEnvironment(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentSiteEnvironment
    _classid_ = 'Microsoft.UI.Content.ContentSiteEnvironment'
    @winrt_mixinmethod
    def put_DisplayId(self: win32more.Microsoft.UI.Content.IContentSiteEnvironment, value: win32more.Microsoft.UI.DisplayId) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayId(self: win32more.Microsoft.UI.Content.IContentSiteEnvironment) -> win32more.Microsoft.UI.DisplayId: ...
    @winrt_mixinmethod
    def put_AppWindowId(self: win32more.Microsoft.UI.Content.IContentSiteEnvironment, value: win32more.Microsoft.UI.WindowId) -> Void: ...
    @winrt_mixinmethod
    def get_View(self: win32more.Microsoft.UI.Content.IContentSiteEnvironment) -> win32more.Microsoft.UI.Content.ContentSiteEnvironmentView: ...
    @winrt_mixinmethod
    def NotifySettingChanged(self: win32more.Microsoft.UI.Content.IContentSiteEnvironment, setting: hstr) -> Void: ...
    @winrt_mixinmethod
    def get_AppWindowId(self: win32more.Microsoft.UI.Content.IContentSiteEnvironment) -> win32more.Microsoft.UI.WindowId: ...
    AppWindowId = property(get_AppWindowId, put_AppWindowId)
    DisplayId = property(get_DisplayId, put_DisplayId)
    View = property(get_View, None)
class ContentSiteEnvironmentView(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentSiteEnvironmentView
    _classid_ = 'Microsoft.UI.Content.ContentSiteEnvironmentView'
    @winrt_mixinmethod
    def get_AppWindowId(self: win32more.Microsoft.UI.Content.IContentSiteEnvironmentView) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_mixinmethod
    def get_DisplayId(self: win32more.Microsoft.UI.Content.IContentSiteEnvironmentView) -> win32more.Microsoft.UI.DisplayId: ...
    AppWindowId = property(get_AppWindowId, None)
    DisplayId = property(get_DisplayId, None)
class ContentSiteRequestedStateChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentSiteRequestedStateChangedEventArgs
    _classid_ = 'Microsoft.UI.Content.ContentSiteRequestedStateChangedEventArgs'
    @winrt_mixinmethod
    def get_DidRequestedSizeChange(self: win32more.Microsoft.UI.Content.IContentSiteRequestedStateChangedEventArgs) -> Boolean: ...
    DidRequestedSizeChange = property(get_DidRequestedSizeChange, None)
class ContentSiteView(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Content.IContentSiteView
    _classid_ = 'Microsoft.UI.Content.ContentSiteView'
    @winrt_mixinmethod
    def get_CoordinateConverter(self: win32more.Microsoft.UI.Content.IContentSiteView) -> win32more.Microsoft.UI.Content.ContentCoordinateConverter: ...
    @winrt_mixinmethod
    def get_ClientSize(self: win32more.Microsoft.UI.Content.IContentSiteView) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_mixinmethod
    def get_ActualSize(self: win32more.Microsoft.UI.Content.IContentSiteView) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def get_DispatcherQueue(self: win32more.Microsoft.UI.Content.IContentSiteView) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_mixinmethod
    def get_EnvironmentView(self: win32more.Microsoft.UI.Content.IContentSiteView) -> win32more.Microsoft.UI.Content.ContentSiteEnvironmentView: ...
    @winrt_mixinmethod
    def get_IsConnected(self: win32more.Microsoft.UI.Content.IContentSiteView) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsSiteEnabled(self: win32more.Microsoft.UI.Content.IContentSiteView) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsSiteVisible(self: win32more.Microsoft.UI.Content.IContentSiteView) -> Boolean: ...
    @winrt_mixinmethod
    def get_LayoutDirection(self: win32more.Microsoft.UI.Content.IContentSiteView) -> win32more.Microsoft.UI.Content.ContentLayoutDirection: ...
    @winrt_mixinmethod
    def get_OverrideScale(self: win32more.Microsoft.UI.Content.IContentSiteView) -> Single: ...
    @winrt_mixinmethod
    def get_ParentScale(self: win32more.Microsoft.UI.Content.IContentSiteView) -> Single: ...
    @winrt_mixinmethod
    def get_RasterizationScale(self: win32more.Microsoft.UI.Content.IContentSiteView) -> Single: ...
    @winrt_mixinmethod
    def get_RequestedSize(self: win32more.Microsoft.UI.Content.IContentSiteView) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_mixinmethod
    def get_ShouldApplyRasterizationScale(self: win32more.Microsoft.UI.Content.IContentSiteView) -> Boolean: ...
    ActualSize = property(get_ActualSize, None)
    ClientSize = property(get_ClientSize, None)
    CoordinateConverter = property(get_CoordinateConverter, None)
    DispatcherQueue = property(get_DispatcherQueue, None)
    EnvironmentView = property(get_EnvironmentView, None)
    IsConnected = property(get_IsConnected, None)
    IsSiteEnabled = property(get_IsSiteEnabled, None)
    IsSiteVisible = property(get_IsSiteVisible, None)
    LayoutDirection = property(get_LayoutDirection, None)
    OverrideScale = property(get_OverrideScale, None)
    ParentScale = property(get_ParentScale, None)
    RasterizationScale = property(get_RasterizationScale, None)
    RequestedSize = property(get_RequestedSize, None)
    ShouldApplyRasterizationScale = property(get_ShouldApplyRasterizationScale, None)
class ContentSizePolicy(Enum, Int32):
    _name_ = 'Microsoft.UI.Content.ContentSizePolicy'
    None_ = 0
    ResizeContentToParentWindow = 1
    ResizeParentWindowToContent = 2
class DesktopChildSiteBridge(ComPtr):
    extends: win32more.Microsoft.UI.Content.DesktopSiteBridge
    default_interface: win32more.Microsoft.UI.Content.IDesktopChildSiteBridge
    _classid_ = 'Microsoft.UI.Content.DesktopChildSiteBridge'
    @winrt_mixinmethod
    def get_ResizePolicy(self: win32more.Microsoft.UI.Content.IDesktopChildSiteBridge) -> win32more.Microsoft.UI.Content.ContentSizePolicy: ...
    @winrt_mixinmethod
    def get_SiteView(self: win32more.Microsoft.UI.Content.IDesktopChildSiteBridge) -> win32more.Microsoft.UI.Content.ContentSiteView: ...
    @winrt_mixinmethod
    def put_ResizePolicy(self: win32more.Microsoft.UI.Content.IDesktopChildSiteBridge, value: win32more.Microsoft.UI.Content.ContentSizePolicy) -> Void: ...
    @winrt_classmethod
    def Create(cls: win32more.Microsoft.UI.Content.IDesktopChildSiteBridgeStatics, compositor: win32more.Microsoft.UI.Composition.Compositor, parentWindowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.UI.Content.DesktopChildSiteBridge: ...
    ResizePolicy = property(get_ResizePolicy, put_ResizePolicy)
    SiteView = property(get_SiteView, None)
class DesktopSiteBridge(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.UI.Content.IDesktopSiteBridge
    _classid_ = 'Microsoft.UI.Content.DesktopSiteBridge'
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def MoveInZOrderBelow(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge, windowId: win32more.Microsoft.UI.WindowId) -> Void: ...
    @winrt_mixinmethod
    def Show(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> Void: ...
    @winrt_mixinmethod
    def put_OverrideScale(self: win32more.Microsoft.UI.Content.IContentSiteBridge, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_IsEnabled(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> Boolean: ...
    @winrt_mixinmethod
    def get_WindowId(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_mixinmethod
    def Connect(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge, content: win32more.Microsoft.UI.Content.ContentIsland) -> Void: ...
    @winrt_mixinmethod
    def Disable(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> Void: ...
    @winrt_mixinmethod
    def Enable(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> Void: ...
    @winrt_mixinmethod
    def Hide(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> Void: ...
    @winrt_mixinmethod
    def MoveAndResize(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge, rect: win32more.Windows.Graphics.RectInt32) -> Void: ...
    @winrt_mixinmethod
    def MoveInZOrderAtBottom(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> Void: ...
    @winrt_mixinmethod
    def MoveInZOrderAtTop(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> Void: ...
    @winrt_mixinmethod
    def get_IsVisible(self: win32more.Microsoft.UI.Content.IDesktopSiteBridge) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsClosed(self: win32more.Microsoft.UI.IClosableNotifier) -> Boolean: ...
    @winrt_mixinmethod
    def add_Closed(self: win32more.Microsoft.UI.IClosableNotifier, handler: win32more.Microsoft.UI.ClosableNotifierHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closed(self: win32more.Microsoft.UI.IClosableNotifier, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_FrameworkClosed(self: win32more.Microsoft.UI.IClosableNotifier, handler: win32more.Microsoft.UI.ClosableNotifierHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FrameworkClosed(self: win32more.Microsoft.UI.IClosableNotifier, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_DispatcherQueue(self: win32more.Microsoft.UI.Content.IContentSiteBridge) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_mixinmethod
    def get_LayoutDirectionOverride(self: win32more.Microsoft.UI.Content.IContentSiteBridge) -> win32more.Windows.Foundation.IReference[win32more.Microsoft.UI.Content.ContentLayoutDirection]: ...
    @winrt_mixinmethod
    def put_LayoutDirectionOverride(self: win32more.Microsoft.UI.Content.IContentSiteBridge, value: win32more.Windows.Foundation.IReference[win32more.Microsoft.UI.Content.ContentLayoutDirection]) -> Void: ...
    @winrt_mixinmethod
    def get_OverrideScale(self: win32more.Microsoft.UI.Content.IContentSiteBridge) -> Single: ...
    @winrt_classmethod
    def IsSupported(cls: win32more.Microsoft.UI.Content.IDesktopSiteBridgeStatics) -> Boolean: ...
    DispatcherQueue = property(get_DispatcherQueue, None)
    IsClosed = property(get_IsClosed, None)
    IsEnabled = property(get_IsEnabled, None)
    IsVisible = property(get_IsVisible, None)
    LayoutDirectionOverride = property(get_LayoutDirectionOverride, put_LayoutDirectionOverride)
    OverrideScale = property(get_OverrideScale, put_OverrideScale)
    WindowId = property(get_WindowId, None)
    Closed = event(add_Closed, remove_Closed)
    FrameworkClosed = event(add_FrameworkClosed, remove_FrameworkClosed)
class IContentCoordinateConverter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentCoordinateConverter'
    _iid_ = Guid('{10a11230-5eb4-5840-a346-570f4a49040f}')
    @winrt_commethod(6)
    def ConvertLocalToScreenWithPoint(self, localPoint: win32more.Windows.Foundation.Point) -> win32more.Windows.Graphics.PointInt32: ...
    @winrt_commethod(7)
    def ConvertLocalToScreenWithPoints(self, localPoints: PassArray[win32more.Windows.Foundation.Point]) -> ReceiveArray[win32more.Windows.Graphics.PointInt32]: ...
    @winrt_commethod(8)
    def ConvertLocalToScreenWithPointsAndRoundingMode(self, localPoints: PassArray[win32more.Windows.Foundation.Point], roundingMode: win32more.Microsoft.UI.Content.ContentCoordinateRoundingMode) -> ReceiveArray[win32more.Windows.Graphics.PointInt32]: ...
    @winrt_commethod(9)
    def ConvertLocalToScreenWithRect(self, localRect: win32more.Windows.Foundation.Rect) -> win32more.Windows.Graphics.RectInt32: ...
    @winrt_commethod(10)
    def ConvertScreenToLocalWithPoint(self, screenPoint: win32more.Windows.Graphics.PointInt32) -> win32more.Windows.Foundation.Point: ...
    @winrt_commethod(11)
    def ConvertScreenToLocalWithPoints(self, screenPoints: PassArray[win32more.Windows.Graphics.PointInt32]) -> ReceiveArray[win32more.Windows.Foundation.Point]: ...
    @winrt_commethod(12)
    def ConvertScreenToLocalWithRect(self, screenRect: win32more.Windows.Graphics.RectInt32) -> win32more.Windows.Foundation.Rect: ...
class IContentCoordinateConverterFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentCoordinateConverterFactory'
    _iid_ = Guid('{a4b216ee-0e26-56bd-9209-a75cf9d80f27}')
class IContentCoordinateConverterStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentCoordinateConverterStatics'
    _iid_ = Guid('{f56374ce-b6df-5b42-a58f-4e3bb039e3a9}')
    @winrt_commethod(6)
    def CreateForWindowId(self, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.UI.Content.ContentCoordinateConverter: ...
class IContentDeferral(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentDeferral'
    _iid_ = Guid('{470529f5-cd93-599b-968e-f8a689bc3a07}')
    @winrt_commethod(6)
    def Complete(self) -> Void: ...
class IContentEnvironmentSettingChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentEnvironmentSettingChangedEventArgs'
    _iid_ = Guid('{76478051-fc80-5eec-a3f3-62606abe06b7}')
    @winrt_commethod(6)
    def get_SettingName(self) -> hstr: ...
    SettingName = property(get_SettingName, None)
class IContentEnvironmentStateChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentEnvironmentStateChangedEventArgs'
    _iid_ = Guid('{8970fa4f-10ba-5f67-970b-8c72bc009b67}')
    @winrt_commethod(6)
    def get_DidAppWindowIdChange(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_DidDisplayIdChange(self) -> Boolean: ...
    DidAppWindowIdChange = property(get_DidAppWindowIdChange, None)
    DidDisplayIdChange = property(get_DidDisplayIdChange, None)
class IContentIsland(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentIsland'
    _iid_ = Guid('{5b2504ba-361c-50aa-bd6e-4122c6d93889}')
    @winrt_commethod(6)
    def get_ActualSize(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(7)
    def get_AppData(self) -> IInspectable: ...
    @winrt_commethod(8)
    def put_AppData(self, value: IInspectable) -> Void: ...
    @winrt_commethod(9)
    def get_CoordinateConverter(self) -> win32more.Microsoft.UI.Content.ContentCoordinateConverter: ...
    @winrt_commethod(10)
    def get_CustomProperties(self) -> win32more.Windows.Foundation.Collections.IPropertySet: ...
    @winrt_commethod(11)
    def get_DispatcherQueue(self) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_commethod(12)
    def get_Environment(self) -> win32more.Microsoft.UI.Content.ContentIslandEnvironment: ...
    @winrt_commethod(13)
    def get_Id(self) -> UInt64: ...
    @winrt_commethod(14)
    def get_IsConnected(self) -> Boolean: ...
    @winrt_commethod(15)
    def get_IsHitTestVisibleWhenTransparent(self) -> Boolean: ...
    @winrt_commethod(16)
    def put_IsHitTestVisibleWhenTransparent(self, value: Boolean) -> Void: ...
    @winrt_commethod(17)
    def get_IsIslandEnabled(self) -> Boolean: ...
    @winrt_commethod(18)
    def put_IsIslandEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(19)
    def get_IsIslandVisible(self) -> Boolean: ...
    @winrt_commethod(20)
    def put_IsIslandVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(21)
    def get_IsSiteEnabled(self) -> Boolean: ...
    @winrt_commethod(22)
    def get_IsSiteVisible(self) -> Boolean: ...
    @winrt_commethod(23)
    def get_LayoutDirection(self) -> win32more.Microsoft.UI.Content.ContentLayoutDirection: ...
    @winrt_commethod(24)
    def get_RasterizationScale(self) -> Single: ...
    @winrt_commethod(25)
    def GetAutomationHostProvider(self) -> IInspectable: ...
    @winrt_commethod(26)
    def GetStateChangeDeferral(self) -> win32more.Microsoft.UI.Content.ContentDeferral: ...
    @winrt_commethod(27)
    def RequestSize(self, size: win32more.Windows.Foundation.Numerics.Vector2) -> Void: ...
    @winrt_commethod(28)
    def add_AutomationProviderRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentIsland, win32more.Microsoft.UI.Content.ContentIslandAutomationProviderRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(29)
    def remove_AutomationProviderRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(30)
    def add_StateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentIsland, win32more.Microsoft.UI.Content.ContentIslandStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(31)
    def remove_StateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ActualSize = property(get_ActualSize, None)
    AppData = property(get_AppData, put_AppData)
    CoordinateConverter = property(get_CoordinateConverter, None)
    CustomProperties = property(get_CustomProperties, None)
    DispatcherQueue = property(get_DispatcherQueue, None)
    Environment = property(get_Environment, None)
    Id = property(get_Id, None)
    IsConnected = property(get_IsConnected, None)
    IsHitTestVisibleWhenTransparent = property(get_IsHitTestVisibleWhenTransparent, put_IsHitTestVisibleWhenTransparent)
    IsIslandEnabled = property(get_IsIslandEnabled, put_IsIslandEnabled)
    IsIslandVisible = property(get_IsIslandVisible, put_IsIslandVisible)
    IsSiteEnabled = property(get_IsSiteEnabled, None)
    IsSiteVisible = property(get_IsSiteVisible, None)
    LayoutDirection = property(get_LayoutDirection, None)
    RasterizationScale = property(get_RasterizationScale, None)
    AutomationProviderRequested = event(add_AutomationProviderRequested, remove_AutomationProviderRequested)
    StateChanged = event(add_StateChanged, remove_StateChanged)
class IContentIslandAutomationProviderRequestedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentIslandAutomationProviderRequestedEventArgs'
    _iid_ = Guid('{9fe24bed-2b9c-5137-887f-403c94841824}')
    @winrt_commethod(6)
    def get_AutomationProvider(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_AutomationProvider(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_Handled(self, value: Boolean) -> Void: ...
    AutomationProvider = property(get_AutomationProvider, put_AutomationProvider)
    Handled = property(get_Handled, put_Handled)
class IContentIslandEnvironment(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentIslandEnvironment'
    _iid_ = Guid('{c334236d-da88-566d-811d-74aef2eba978}')
    @winrt_commethod(6)
    def get_AppWindowId(self) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_commethod(7)
    def get_DisplayId(self) -> win32more.Microsoft.UI.DisplayId: ...
    @winrt_commethod(8)
    def add_SettingChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentIslandEnvironment, win32more.Microsoft.UI.Content.ContentEnvironmentSettingChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_SettingChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def add_StateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentIslandEnvironment, win32more.Microsoft.UI.Content.ContentEnvironmentStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_StateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AppWindowId = property(get_AppWindowId, None)
    DisplayId = property(get_DisplayId, None)
    SettingChanged = event(add_SettingChanged, remove_SettingChanged)
    StateChanged = event(add_StateChanged, remove_StateChanged)
class IContentIslandEnvironmentFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentIslandEnvironmentFactory'
    _iid_ = Guid('{47a782d6-b177-5c1e-bf87-90437dd809d0}')
class IContentIslandFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentIslandFactory'
    _iid_ = Guid('{82383f52-e81a-5ec9-a954-bac8a931ba7d}')
class IContentIslandStateChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentIslandStateChangedEventArgs'
    _iid_ = Guid('{c828eeb2-0c62-5b40-9d48-77c06083c278}')
    @winrt_commethod(6)
    def get_DidActualSizeChange(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_DidSiteEnabledChange(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_DidSiteVisibleChange(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_DidLayoutDirectionChange(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_DidRasterizationScaleChange(self) -> Boolean: ...
    DidActualSizeChange = property(get_DidActualSizeChange, None)
    DidLayoutDirectionChange = property(get_DidLayoutDirectionChange, None)
    DidRasterizationScaleChange = property(get_DidRasterizationScaleChange, None)
    DidSiteEnabledChange = property(get_DidSiteEnabledChange, None)
    DidSiteVisibleChange = property(get_DidSiteVisibleChange, None)
class IContentIslandStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentIslandStatics'
    _iid_ = Guid('{7b9eb7cc-8c43-5e0a-ab23-ab48628fd223}')
    @winrt_commethod(6)
    def Create(self, Root: win32more.Microsoft.UI.Composition.Visual) -> win32more.Microsoft.UI.Content.ContentIsland: ...
    @winrt_commethod(7)
    def FindAllForCompositor(self, compositor: win32more.Microsoft.UI.Composition.Compositor) -> ReceiveArray[win32more.Microsoft.UI.Content.ContentIsland]: ...
    @winrt_commethod(8)
    def FindAllForCurrentThread(self) -> ReceiveArray[win32more.Microsoft.UI.Content.ContentIsland]: ...
    @winrt_commethod(9)
    def GetByVisual(self, child: win32more.Microsoft.UI.Composition.Visual) -> win32more.Microsoft.UI.Content.ContentIsland: ...
    @winrt_commethod(10)
    def GetFromId(self, id: UInt64) -> win32more.Microsoft.UI.Content.ContentIsland: ...
class IContentSite(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSite'
    _iid_ = Guid('{996c60c4-02b2-5eef-93b0-dd6b1ec2fd7b}')
    @winrt_commethod(6)
    def get_ActualSize(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(7)
    def put_ActualSize(self, value: win32more.Windows.Foundation.Numerics.Vector2) -> Void: ...
    @winrt_commethod(8)
    def get_ClientSize(self) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_commethod(9)
    def put_ClientSize(self, value: win32more.Windows.Graphics.SizeInt32) -> Void: ...
    @winrt_commethod(10)
    def get_CoordinateConverter(self) -> win32more.Microsoft.UI.Content.ContentCoordinateConverter: ...
    @winrt_commethod(11)
    def get_DispatcherQueue(self) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_commethod(12)
    def get_Environment(self) -> win32more.Microsoft.UI.Content.ContentSiteEnvironment: ...
    @winrt_commethod(13)
    def get_IsConnected(self) -> Boolean: ...
    @winrt_commethod(14)
    def get_IsSiteEnabled(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsSiteEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_IsSiteVisible(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsSiteVisible(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_LayoutDirection(self) -> win32more.Microsoft.UI.Content.ContentLayoutDirection: ...
    @winrt_commethod(19)
    def put_LayoutDirection(self, value: win32more.Microsoft.UI.Content.ContentLayoutDirection) -> Void: ...
    @winrt_commethod(20)
    def get_OverrideScale(self) -> Single: ...
    @winrt_commethod(21)
    def put_OverrideScale(self, value: Single) -> Void: ...
    @winrt_commethod(22)
    def get_ParentScale(self) -> Single: ...
    @winrt_commethod(23)
    def put_ParentScale(self, value: Single) -> Void: ...
    @winrt_commethod(24)
    def get_RasterizationScale(self) -> Single: ...
    @winrt_commethod(25)
    def get_RequestedSize(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(26)
    def get_ShouldApplyRasterizationScale(self) -> Boolean: ...
    @winrt_commethod(27)
    def put_ShouldApplyRasterizationScale(self, value: Boolean) -> Void: ...
    @winrt_commethod(28)
    def get_View(self) -> win32more.Microsoft.UI.Content.ContentSiteView: ...
    @winrt_commethod(29)
    def GetIslandStateChangeDeferral(self) -> win32more.Microsoft.UI.Content.ContentDeferral: ...
    @winrt_commethod(30)
    def add_RequestedStateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Content.ContentSite, win32more.Microsoft.UI.Content.ContentSiteRequestedStateChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(31)
    def remove_RequestedStateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ActualSize = property(get_ActualSize, put_ActualSize)
    ClientSize = property(get_ClientSize, put_ClientSize)
    CoordinateConverter = property(get_CoordinateConverter, None)
    DispatcherQueue = property(get_DispatcherQueue, None)
    Environment = property(get_Environment, None)
    IsConnected = property(get_IsConnected, None)
    IsSiteEnabled = property(get_IsSiteEnabled, put_IsSiteEnabled)
    IsSiteVisible = property(get_IsSiteVisible, put_IsSiteVisible)
    LayoutDirection = property(get_LayoutDirection, put_LayoutDirection)
    OverrideScale = property(get_OverrideScale, put_OverrideScale)
    ParentScale = property(get_ParentScale, put_ParentScale)
    RasterizationScale = property(get_RasterizationScale, None)
    RequestedSize = property(get_RequestedSize, None)
    ShouldApplyRasterizationScale = property(get_ShouldApplyRasterizationScale, put_ShouldApplyRasterizationScale)
    View = property(get_View, None)
    RequestedStateChanged = event(add_RequestedStateChanged, remove_RequestedStateChanged)
class IContentSiteBridge(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Microsoft.UI.Content.IContentSiteBridge'
    _iid_ = Guid('{faaab99e-a42b-549c-92df-3b6d6e1e368b}')
    @winrt_commethod(6)
    def get_DispatcherQueue(self) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_commethod(7)
    def get_LayoutDirectionOverride(self) -> win32more.Windows.Foundation.IReference[win32more.Microsoft.UI.Content.ContentLayoutDirection]: ...
    @winrt_commethod(8)
    def put_LayoutDirectionOverride(self, value: win32more.Windows.Foundation.IReference[win32more.Microsoft.UI.Content.ContentLayoutDirection]) -> Void: ...
    @winrt_commethod(9)
    def get_OverrideScale(self) -> Single: ...
    @winrt_commethod(10)
    def put_OverrideScale(self, value: Single) -> Void: ...
    DispatcherQueue = property(get_DispatcherQueue, None)
    LayoutDirectionOverride = property(get_LayoutDirectionOverride, put_LayoutDirectionOverride)
    OverrideScale = property(get_OverrideScale, put_OverrideScale)
class IContentSiteEnvironment(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSiteEnvironment'
    _iid_ = Guid('{685d085d-be53-55d1-aec4-ba2273d5468b}')
    @winrt_commethod(6)
    def get_AppWindowId(self) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_commethod(7)
    def put_AppWindowId(self, value: win32more.Microsoft.UI.WindowId) -> Void: ...
    @winrt_commethod(8)
    def get_DisplayId(self) -> win32more.Microsoft.UI.DisplayId: ...
    @winrt_commethod(9)
    def put_DisplayId(self, value: win32more.Microsoft.UI.DisplayId) -> Void: ...
    @winrt_commethod(10)
    def get_View(self) -> win32more.Microsoft.UI.Content.ContentSiteEnvironmentView: ...
    @winrt_commethod(11)
    def NotifySettingChanged(self, setting: hstr) -> Void: ...
    AppWindowId = property(get_AppWindowId, put_AppWindowId)
    DisplayId = property(get_DisplayId, put_DisplayId)
    View = property(get_View, None)
class IContentSiteEnvironmentFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSiteEnvironmentFactory'
    _iid_ = Guid('{0befa998-cb15-5f16-a4a5-c0ed1674e186}')
class IContentSiteEnvironmentView(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSiteEnvironmentView'
    _iid_ = Guid('{5b6fe420-0bb3-54dd-8589-786cf02e38f1}')
    @winrt_commethod(6)
    def get_AppWindowId(self) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_commethod(7)
    def get_DisplayId(self) -> win32more.Microsoft.UI.DisplayId: ...
    AppWindowId = property(get_AppWindowId, None)
    DisplayId = property(get_DisplayId, None)
class IContentSiteEnvironmentViewFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSiteEnvironmentViewFactory'
    _iid_ = Guid('{c901edf2-f184-5a64-8d58-8cf8efa8b678}')
class IContentSiteFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSiteFactory'
    _iid_ = Guid('{72fb98d5-b28a-57f1-91fa-24c014a342c1}')
class IContentSiteRequestedStateChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSiteRequestedStateChangedEventArgs'
    _iid_ = Guid('{1b55fd1d-7292-562b-b4a1-d4de7972e684}')
    @winrt_commethod(6)
    def get_DidRequestedSizeChange(self) -> Boolean: ...
    DidRequestedSizeChange = property(get_DidRequestedSizeChange, None)
class IContentSiteView(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSiteView'
    _iid_ = Guid('{2d5d8dd5-358e-5b05-993b-b2666d1786b3}')
    @winrt_commethod(6)
    def get_ActualSize(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(7)
    def get_ClientSize(self) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_commethod(8)
    def get_CoordinateConverter(self) -> win32more.Microsoft.UI.Content.ContentCoordinateConverter: ...
    @winrt_commethod(9)
    def get_DispatcherQueue(self) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_commethod(10)
    def get_EnvironmentView(self) -> win32more.Microsoft.UI.Content.ContentSiteEnvironmentView: ...
    @winrt_commethod(11)
    def get_IsConnected(self) -> Boolean: ...
    @winrt_commethod(12)
    def get_IsSiteEnabled(self) -> Boolean: ...
    @winrt_commethod(13)
    def get_IsSiteVisible(self) -> Boolean: ...
    @winrt_commethod(14)
    def get_LayoutDirection(self) -> win32more.Microsoft.UI.Content.ContentLayoutDirection: ...
    @winrt_commethod(15)
    def get_OverrideScale(self) -> Single: ...
    @winrt_commethod(16)
    def get_ParentScale(self) -> Single: ...
    @winrt_commethod(17)
    def get_RasterizationScale(self) -> Single: ...
    @winrt_commethod(18)
    def get_RequestedSize(self) -> win32more.Windows.Foundation.Numerics.Vector2: ...
    @winrt_commethod(19)
    def get_ShouldApplyRasterizationScale(self) -> Boolean: ...
    ActualSize = property(get_ActualSize, None)
    ClientSize = property(get_ClientSize, None)
    CoordinateConverter = property(get_CoordinateConverter, None)
    DispatcherQueue = property(get_DispatcherQueue, None)
    EnvironmentView = property(get_EnvironmentView, None)
    IsConnected = property(get_IsConnected, None)
    IsSiteEnabled = property(get_IsSiteEnabled, None)
    IsSiteVisible = property(get_IsSiteVisible, None)
    LayoutDirection = property(get_LayoutDirection, None)
    OverrideScale = property(get_OverrideScale, None)
    ParentScale = property(get_ParentScale, None)
    RasterizationScale = property(get_RasterizationScale, None)
    RequestedSize = property(get_RequestedSize, None)
    ShouldApplyRasterizationScale = property(get_ShouldApplyRasterizationScale, None)
class IContentSiteViewFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IContentSiteViewFactory'
    _iid_ = Guid('{9efd72f0-63ef-5b6a-a50c-5685bd8100f1}')
class IDesktopChildSiteBridge(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IDesktopChildSiteBridge'
    _iid_ = Guid('{b2f2ff7b-1825-51b0-b80b-7599889c569f}')
    @winrt_commethod(6)
    def get_ResizePolicy(self) -> win32more.Microsoft.UI.Content.ContentSizePolicy: ...
    @winrt_commethod(7)
    def put_ResizePolicy(self, value: win32more.Microsoft.UI.Content.ContentSizePolicy) -> Void: ...
    @winrt_commethod(8)
    def get_SiteView(self) -> win32more.Microsoft.UI.Content.ContentSiteView: ...
    ResizePolicy = property(get_ResizePolicy, put_ResizePolicy)
    SiteView = property(get_SiteView, None)
class IDesktopChildSiteBridgeStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IDesktopChildSiteBridgeStatics'
    _iid_ = Guid('{ab6b82de-6a47-5de3-a860-613c8db679ab}')
    @winrt_commethod(6)
    def Create(self, compositor: win32more.Microsoft.UI.Composition.Compositor, parentWindowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.UI.Content.DesktopChildSiteBridge: ...
class IDesktopSiteBridge(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IDesktopSiteBridge'
    _iid_ = Guid('{f0ae8750-905c-50a2-8a12-4545c6245bb4}')
    @winrt_commethod(6)
    def get_IsEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_IsVisible(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_WindowId(self) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_commethod(9)
    def Connect(self, content: win32more.Microsoft.UI.Content.ContentIsland) -> Void: ...
    @winrt_commethod(10)
    def Disable(self) -> Void: ...
    @winrt_commethod(11)
    def Enable(self) -> Void: ...
    @winrt_commethod(12)
    def Hide(self) -> Void: ...
    @winrt_commethod(13)
    def MoveAndResize(self, rect: win32more.Windows.Graphics.RectInt32) -> Void: ...
    @winrt_commethod(14)
    def MoveInZOrderAtBottom(self) -> Void: ...
    @winrt_commethod(15)
    def MoveInZOrderAtTop(self) -> Void: ...
    @winrt_commethod(16)
    def MoveInZOrderBelow(self, windowId: win32more.Microsoft.UI.WindowId) -> Void: ...
    @winrt_commethod(17)
    def Show(self) -> Void: ...
    IsEnabled = property(get_IsEnabled, None)
    IsVisible = property(get_IsVisible, None)
    WindowId = property(get_WindowId, None)
class IDesktopSiteBridgeFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IDesktopSiteBridgeFactory'
    _iid_ = Guid('{d94ee1ff-3af1-54d0-9311-652b29c57c5b}')
class IDesktopSiteBridgeStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Content.IDesktopSiteBridgeStatics'
    _iid_ = Guid('{e0b38daf-9cd4-50c5-83ee-c76e3cf34eba}')
    @winrt_commethod(6)
    def IsSupported(self) -> Boolean: ...


make_ready(__name__)
